/*
 * Copyright © 2013 Keith Packard <keithp@keithp.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 */

package org.altusmetrum.altoslib_12;

public interface AltosEepromMonitor {

	public void set_block(int in_block);

	public void set_max(int in_max);

	public void set_serial(int in_serial);

	public void set_flight(int in_flight);

	public void set_filename(String in_file);

	public void set_thread(Thread eeprom_thread);

	final static int INFO_MESSAGE = 0;
	final static int WARNING_MESSAGE = 1;
	final static int ERROR_MESSAGE = 2;

	public void show_message(String message, String title, int message_type);

	public void start();

	public void done(boolean success);

	public void reset();
}
